/*
 *
 *  oFono - Open Source Telephony
 *
 *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include "atutil.h"

extern void at_netreg_init(void);
extern void at_netreg_exit(void);

extern void at_call_forwarding_init(void);
extern void at_call_forwarding_exit(void);

extern void at_call_settings_init(void);
extern void at_call_settings_exit(void);

extern void at_ussd_init(void);
extern void at_ussd_exit(void);

extern void at_voicecall_init(void);
extern void at_voicecall_exit(void);

extern void at_call_meter_init(void);
extern void at_call_meter_exit(void);

extern void at_call_barring_init(void);
extern void at_call_barring_exit(void);

extern void at_sim_init(void);
extern void at_sim_exit(void);

extern void at_stk_init(void);
extern void at_stk_exit(void);

extern void at_sms_init(void);
extern void at_sms_exit(void);

extern void at_phonebook_init(void);
extern void at_phonebook_exit(void);

extern void at_devinfo_init(void);
extern void at_devinfo_exit(void);

extern void at_cbs_init(void);
extern void at_cbs_exit(void);

extern void at_call_volume_init(void);
extern void at_call_volume_exit(void);

extern void at_gprs_init(void);
extern void at_gprs_exit(void);

extern void at_gprs_context_init(void);
extern void at_gprs_context_exit(void);

extern void at_sim_auth_init(void);
extern void at_sim_auth_exit(void);

extern void at_gnss_init(void);
extern void at_gnss_exit(void);
